@@ -27,7 +27,6 @@
 #define _DOWNTIME_H
 
 #include "compat.h"
-#include "config.h"
 #include "common.h"
 #include "objects.h"
 
@@ -40,18 +39,22 @@ typedef struct scheduled_downtime_struct {
 	char *service_description;
 	time_t entry_time;
 	time_t start_time;
+	time_t flex_downtime_start;		/* Time the flexible downtime started */
 	time_t end_time;
 	int fixed;
 	unsigned long triggered_by;
 	unsigned long duration;
 	unsigned long downtime_id;
 	int is_in_effect;
+	int	start_notification_sent;
 	char *author;
 	char *comment;
 #ifdef NSCORE
 	unsigned long comment_id;
 	int start_flex_downtime;
 	int incremented_pending_downtime;
+//	int start_event; 
+//	int stop_event;
 #endif
 	struct scheduled_downtime_struct *next;
 	} scheduled_downtime;
@@ -62,9 +65,9 @@ typedef struct scheduled_downtime_struct {
 int initialize_downtime_data(char *);                                /* initializes scheduled downtime data */
 int cleanup_downtime_data(char *);                                   /* cleans up scheduled downtime data */
 
-int add_new_downtime(int, char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long *, int);
-int add_new_host_downtime(char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long *, int);
-int add_new_service_downtime(char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long *, int);
+int add_new_downtime(int, char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long *, int, int);
+int add_new_host_downtime(char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long *, int, int);
+int add_new_service_downtime(char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long *, int, int);
 
 int delete_host_downtime(unsigned long);
 int delete_service_downtime(unsigned long);
@@ -83,15 +86,15 @@ int check_pending_flex_service_downtime(service *);
 int check_for_expired_downtime(void);
 #endif
 
-int add_host_downtime(char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long, int);
-int add_service_downtime(char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long, int);
+int add_host_downtime(char *, time_t, char *, char *, time_t, time_t, time_t, int, unsigned long, unsigned long, unsigned long, int, int);
+int add_service_downtime(char *, char *, time_t, char *, char *, time_t, time_t, time_t, int, unsigned long, unsigned long, unsigned long, int, int);
 
 /* If you are going to be adding a lot of downtime in sequence, set
    defer_downtime_sorting to 1 before you start and then call
    sort_downtime afterwards. Things will go MUCH faster. */
 
 extern int defer_downtime_sorting;
-int add_downtime(int, char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long, int);
+int add_downtime(int, char *, char *, time_t, char *, char *, time_t, time_t, time_t, int, unsigned long, unsigned long, unsigned long, int, int);
 int sort_downtime(void);
 
 scheduled_downtime *find_downtime(int, unsigned long);
