@@ -22,15 +22,12 @@
  *
  *****************************************************************************/
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include "compat.h"
+NAGIOS_BEGIN_DECL
 
-	int initialize_retention_data(char *);
-	int cleanup_retention_data(char *);
-	int save_state_information(int);                 /* saves all host and state information */
-	int read_initial_state_information(void);        /* reads in initial host and state information */
+int initialize_retention_data(char *);
+int cleanup_retention_data(char *);
+int save_state_information(int);                 /* saves all host and state information */
+int read_initial_state_information(void);        /* reads in initial host and state information */
 
-#ifdef __cplusplus
-	}
-#endif
+NAGIOS_END_DECL
